@@ -2,7 +2,7 @@ package PDF::Extract;
 use strict;
 #use warnings;
 use vars qw($VERSION);
-$VERSION = '3.01';
+$VERSION = '3.03';
 
 =head1 NAME
 
@@ -640,7 +640,7 @@ sub getRoot {
 
 sub getObj {
 	return "" if $vars{"PDFError"};
-    my($obj,$instnum)=@_;
+    my($obj,$instnum,$gd)=@_;
     unless ($obj[$obj] ) {
          if ($pdf=~/\D($obj $instnum obj.*?endobj\s*)/s ) {
             $object = $1;
@@ -650,14 +650,14 @@ sub getObj {
             $instnum[$obj]=$instnum;
             
 	        $object[$obj]=~s/(\/Dest \[ )(\d+)( \d.*?)/&uri($1,$2,$3)/es; # Convert page dest to uri if not present
-	        $object[$obj]=~s/(\d+) (\d+) R/&getObj($1, $2 )/ges;
+	        $object[$obj]=~s/(\d+) (\d+) R([^GD])/&getObj($1, $2, $3)/ges; # Reported bug 33707 found 0 0 R in 0 0 0 RG generated by BUFFETTI software 
 #	        $object[$obj]=~s/(\/Dest \[ \d+)==/$1 0/s; # Don't follow this path
 	        $object[$obj]=~s/\/Annots \[\s+\]\s+//s; # Delete empty Annots array
 	    } else {
 	        &error("Can't find object $obj $instnum obj  ",__FILE__,__LINE__);
 	    }
     }
-    "$obj 0 R";
+    "$obj 0 R$gd";
 }
 
 sub uri {
@@ -765,6 +765,7 @@ Much thanks to:-
  Stefano Capuzzimato for correcting some stuff in the regexes he found.
  Geert Theys for finding a small bug and supplying an excelent solution.
  Jon Schaeffer for help with finding a solution to a bug in extracting Adobe 6+ pages.
+ Dario Santini for reporting a bug at http://rt.cpan.org//Ticket/Display.html?id=33707
  
 =head1 COPYRIGHT
 
